Model Package
=============

:mod:`Model` Package
--------------------

.. automodule:: pynag.Model
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`all_attributes` Module
----------------------------

.. automodule:: pynag.Model.all_attributes
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`macros` Module
--------------------

.. automodule:: pynag.Model.macros
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    pynag.Model.EventHandlers

